"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const Header_1 = __importDefault(require("../Header"));
const Linear_1 = __importDefault(require("../Linear"));
const style_1 = __importDefault(require("./style"));
;
const Container = ({ header, style = {}, styleScroll = {}, linear, children = null, safeView = true, scrollView = true, onScroll, footer, }) => {
    const renderScroll = () => {
        if (scrollView) {
            if (onScroll) {
                return (<react_native_1.ScrollView style={[styleScroll]} onScroll={onScroll} scrollEventThrottle={1}>
                        {children}
                    </react_native_1.ScrollView>);
            }
            return (<react_native_1.ScrollView style={[styleScroll]}>
                    {children}
                </react_native_1.ScrollView>);
        }
        return children;
    };
    const renderView = () => {
        if (!header)
            return null;
        let _styles = [
            style_1.default.container,
            style
        ];
        let _header = header;
        if (linear) {
            _styles = [
                style_1.default.container,
                style,
                {
                    zIndex: 2,
                    position: 'relative',
                    backgroundColor: 'none',
                }
            ];
            if (_header.style) {
                _header.style = Object.assign(Object.assign({}, _header.style), { backgroundColor: 'none' });
            }
            else {
                _header.style = {
                    backgroundColor: 'none',
                };
            }
        }
        return (<react_native_1.View style={_styles}>
                <Header_1.default {..._header}/>
                {renderScroll()}
                {footer ? (<react_native_1.SafeAreaView style={[footer.style || {}]}>
                            {footer.children}
                        </react_native_1.SafeAreaView>) : null}
            </react_native_1.View>);
    };
    const renderFull = () => {
        if (header)
            return null;
        if (safeView) {
            return (<react_native_1.SafeAreaView style={[style_1.default.container, style]}>
                    {renderScroll()}
                </react_native_1.SafeAreaView>);
        }
        return (<react_native_1.View style={[style_1.default.container, style]}>
                {renderScroll()}
            </react_native_1.View>);
    };
    const renderLinear = () => {
        if (!linear)
            return null;
        if (linear === true) {
            return <Linear_1.default />;
        }
        else {
            return <Linear_1.default {...linear}/>;
        }
    };
    return (<>
            {renderLinear()}
            {renderFull()}
            {renderView()}
        </>);
};
exports.default = Container;
